@@ -91,7 +91,7 @@ async def cyberdrop_parse(url: URL) -> URL:
 
 async def check_direct(url: URL):
     mapping_direct = ['i.pixl.is', r's..putmega.com', r's..putme.ga', r'img-...cyberdrop...', r'f.cyberdrop...',
-                      r'fs-...cyberdrop...', r'cdn.bunkr...', r'media-files.bunkr...', r'jpg.church/images/...',
+                      r'fs-...cyberdrop...', r'cdn.bunkr...', r'cdn..bunkr...', r'media-files.bunkr...', r'jpg.church/images/...',
                       r'simp..jpg.church']
     for domain in mapping_direct:
         extension = '.' + str(url).split('.')[-1]
