@@ -81,7 +81,7 @@ class Downloader:
 
         self.max_workers = max_workers
         self._semaphore = asyncio.Semaphore(max_workers)
-        self.delay = {'cyberfile.is': 1}
+        self.delay = {'cyberfile.is': 1, 'anonfiles.com': 1}
         self.throttle_times = {}
 
     """Changed from aiohttp exceptions caught to FailureException to allow for partial downloads."""
@@ -319,8 +319,8 @@ async def get_downloaders(Cascade: CascadeItem, folder: Path, attempts: int, dis
 
     for domain, domain_obj in Cascade.domains.items():
         max_workers = threads if threads != 0 else multiprocessing.cpu_count()
-        if 'bunkr' in domain or 'pixeldrain' in domain:
-            max_workers = 3 if (max_workers > 3) else max_workers
+        if 'bunkr' in domain or 'pixeldrain' in domain or 'anonfiles' in domain:
+            max_workers = 2 if (max_workers > 2) else max_workers
         for title, album_obj in domain_obj.albums.items():
             downloader = Downloader(album_obj, cookie_jar=cookie_jar, title=title, folder=folder,
                                     attempts=attempts, disable_attempt_limit=disable_attempt_limit,
